mockdata

package
v0.12.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 29, 2026 License: LGPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockFormalExpression

type MockFormalExpression struct {
	mock.Mock
}

MockFormalExpression is an autogenerated mock type for the FormalExpression type

func NewMockFormalExpression

func NewMockFormalExpression(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockFormalExpression

NewMockFormalExpression creates a new instance of MockFormalExpression. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockFormalExpression) Docs

Docs provides a mock function for the type MockFormalExpression

func (*MockFormalExpression) EXPECT

func (*MockFormalExpression) Evaluate

func (_mock *MockFormalExpression) Evaluate(ctx context.Context, source data.Source) (data.Value, error)

Evaluate provides a mock function for the type MockFormalExpression

func (*MockFormalExpression) ID

func (_mock *MockFormalExpression) ID() string

ID provides a mock function for the type MockFormalExpression

func (*MockFormalExpression) IsEvaluated

func (_mock *MockFormalExpression) IsEvaluated() bool

IsEvaluated provides a mock function for the type MockFormalExpression

func (*MockFormalExpression) Language

func (_mock *MockFormalExpression) Language() string

Language provides a mock function for the type MockFormalExpression

func (*MockFormalExpression) Result

func (_mock *MockFormalExpression) Result() (data.Value, error)

Result provides a mock function for the type MockFormalExpression

func (*MockFormalExpression) ResultType

func (_mock *MockFormalExpression) ResultType() string

ResultType provides a mock function for the type MockFormalExpression

type MockFormalExpression_Docs_Call

type MockFormalExpression_Docs_Call struct {
	*mock.Call
}

MockFormalExpression_Docs_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Docs'

func (*MockFormalExpression_Docs_Call) Return

func (*MockFormalExpression_Docs_Call) Run

func (*MockFormalExpression_Docs_Call) RunAndReturn

type MockFormalExpression_Evaluate_Call

type MockFormalExpression_Evaluate_Call struct {
	*mock.Call
}

MockFormalExpression_Evaluate_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Evaluate'

func (*MockFormalExpression_Evaluate_Call) Return

func (*MockFormalExpression_Evaluate_Call) Run

func (*MockFormalExpression_Evaluate_Call) RunAndReturn

type MockFormalExpression_Expecter

type MockFormalExpression_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockFormalExpression_Expecter) Docs

Docs is a helper method to define mock.On call

func (*MockFormalExpression_Expecter) Evaluate

func (_e *MockFormalExpression_Expecter) Evaluate(ctx interface{}, source interface{}) *MockFormalExpression_Evaluate_Call

Evaluate is a helper method to define mock.On call

  • ctx context.Context
  • source data.Source

func (*MockFormalExpression_Expecter) ID

ID is a helper method to define mock.On call

func (*MockFormalExpression_Expecter) IsEvaluated

IsEvaluated is a helper method to define mock.On call

func (*MockFormalExpression_Expecter) Language

Language is a helper method to define mock.On call

func (*MockFormalExpression_Expecter) Result

Result is a helper method to define mock.On call

func (*MockFormalExpression_Expecter) ResultType

ResultType is a helper method to define mock.On call

type MockFormalExpression_ID_Call

type MockFormalExpression_ID_Call struct {
	*mock.Call
}

MockFormalExpression_ID_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ID'

func (*MockFormalExpression_ID_Call) Return

func (*MockFormalExpression_ID_Call) Run

func (*MockFormalExpression_ID_Call) RunAndReturn

type MockFormalExpression_IsEvaluated_Call

type MockFormalExpression_IsEvaluated_Call struct {
	*mock.Call
}

MockFormalExpression_IsEvaluated_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'IsEvaluated'

func (*MockFormalExpression_IsEvaluated_Call) Return

func (*MockFormalExpression_IsEvaluated_Call) Run

func (*MockFormalExpression_IsEvaluated_Call) RunAndReturn

type MockFormalExpression_Language_Call

type MockFormalExpression_Language_Call struct {
	*mock.Call
}

MockFormalExpression_Language_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Language'

func (*MockFormalExpression_Language_Call) Return

func (*MockFormalExpression_Language_Call) Run

func (*MockFormalExpression_Language_Call) RunAndReturn

type MockFormalExpression_ResultType_Call

type MockFormalExpression_ResultType_Call struct {
	*mock.Call
}

MockFormalExpression_ResultType_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ResultType'

func (*MockFormalExpression_ResultType_Call) Return

func (*MockFormalExpression_ResultType_Call) Run

func (*MockFormalExpression_ResultType_Call) RunAndReturn

type MockFormalExpression_Result_Call

type MockFormalExpression_Result_Call struct {
	*mock.Call
}

MockFormalExpression_Result_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Result'

func (*MockFormalExpression_Result_Call) Return

func (*MockFormalExpression_Result_Call) Run

func (*MockFormalExpression_Result_Call) RunAndReturn

type MockPropertyAdder

type MockPropertyAdder struct {
	mock.Mock
}

MockPropertyAdder is an autogenerated mock type for the PropertyAdder type

func NewMockPropertyAdder

func NewMockPropertyAdder(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockPropertyAdder

NewMockPropertyAdder creates a new instance of MockPropertyAdder. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockPropertyAdder) AddProperty

func (_mock *MockPropertyAdder) AddProperty(p *data.Property) error

AddProperty provides a mock function for the type MockPropertyAdder

func (*MockPropertyAdder) EXPECT

func (*MockPropertyAdder) Validate

func (_mock *MockPropertyAdder) Validate() error

Validate provides a mock function for the type MockPropertyAdder

type MockPropertyAdder_AddProperty_Call

type MockPropertyAdder_AddProperty_Call struct {
	*mock.Call
}

MockPropertyAdder_AddProperty_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'AddProperty'

func (*MockPropertyAdder_AddProperty_Call) Return

func (*MockPropertyAdder_AddProperty_Call) Run

func (*MockPropertyAdder_AddProperty_Call) RunAndReturn

type MockPropertyAdder_Expecter

type MockPropertyAdder_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockPropertyAdder_Expecter) AddProperty

func (_e *MockPropertyAdder_Expecter) AddProperty(p interface{}) *MockPropertyAdder_AddProperty_Call

AddProperty is a helper method to define mock.On call

  • p *data.Property

func (*MockPropertyAdder_Expecter) Validate

Validate is a helper method to define mock.On call

type MockPropertyAdder_Validate_Call

type MockPropertyAdder_Validate_Call struct {
	*mock.Call
}

MockPropertyAdder_Validate_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Validate'

func (*MockPropertyAdder_Validate_Call) Return

func (*MockPropertyAdder_Validate_Call) Run

func (*MockPropertyAdder_Validate_Call) RunAndReturn

type MockSource

type MockSource struct {
	mock.Mock
}

MockSource is an autogenerated mock type for the Source type

func NewMockSource

func NewMockSource(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockSource

NewMockSource creates a new instance of MockSource. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockSource) EXPECT

func (_m *MockSource) EXPECT() *MockSource_Expecter

func (*MockSource) Find

func (_mock *MockSource) Find(ctx context.Context, name string) (data.Data, error)

Find provides a mock function for the type MockSource

type MockSource_Expecter

type MockSource_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockSource_Expecter) Find

func (_e *MockSource_Expecter) Find(ctx interface{}, name interface{}) *MockSource_Find_Call

Find is a helper method to define mock.On call

  • ctx context.Context
  • name string

type MockSource_Find_Call

type MockSource_Find_Call struct {
	*mock.Call
}

MockSource_Find_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Find'

func (*MockSource_Find_Call) Return

func (_c *MockSource_Find_Call) Return(data1 data.Data, err error) *MockSource_Find_Call

func (*MockSource_Find_Call) Run

func (_c *MockSource_Find_Call) Run(run func(ctx context.Context, name string)) *MockSource_Find_Call

func (*MockSource_Find_Call) RunAndReturn

func (_c *MockSource_Find_Call) RunAndReturn(run func(ctx context.Context, name string) (data.Data, error)) *MockSource_Find_Call

Jump to